@@ -59,8 +59,13 @@ class App:
         self._lock = threading.Lock()
         self._events: queue.Queue[EventWrapper] = queue.Queue()
         self._index: faiss.Index | None = None
+        self._index_updated = threading.Condition()
 
-    def _index_worker(self, path: Path):
+    @property
+    def index_updated_condition(self) -> threading.Condition:
+        return self._index_updated
+
+    def _index_worker(self, path: Path) -> T.NoReturn:
         while True:
             try:
                 logger.debug(f"Index worker {path}")
@@ -84,8 +89,9 @@ class App:
                     with STATS.timer("codebased.index.worker.duration"):
                         self._index = index
                         STATS.increment("codebased.perform_search.cache_clear")
-                        # lmao
                         self.perform_search.cache_clear()
+                with self._index_updated:
+                    self._index_updated.notify_all()
             except Exception as e:
                 logger.exception(f"Exception in index worker: {e} (ignored)")
 
